package com.jiuqi.util.csv;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.StringReader;
import java.nio.charset.Charset;
import java.text.NumberFormat;
import java.util.HashMap;

/* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader.class */
public class CsvReader {
    private Reader inputStream;
    private String fileName;
    private UserSettings userSettings;
    private Charset charset;
    private boolean useCustomRecordDelimiter;
    private DataBuffer dataBuffer;
    private ColumnBuffer columnBuffer;
    private RawRecordBuffer rawBuffer;
    private boolean[] isQualified;
    private String rawRecord;
    private HeadersHolder headersHolder;
    private boolean startedColumn;
    private boolean startedWithQualifier;
    private boolean hasMoreData;
    private char lastLetter;
    private boolean hasReadNextLine;
    private int columnsCount;
    private long currentRecord;
    private String[] values;
    private boolean initialized;
    private boolean closed;
    public static final int ESCAPE_MODE_DOUBLED = 1;
    public static final int ESCAPE_MODE_BACKSLASH = 2;

    public CsvReader(String fileName, char delimiter, Charset charset) throws FileNotFoundException {
        this.inputStream = null;
        this.fileName = null;
        this.userSettings = new UserSettings();
        this.charset = null;
        this.useCustomRecordDelimiter = false;
        this.dataBuffer = new DataBuffer();
        this.columnBuffer = new ColumnBuffer();
        this.rawBuffer = new RawRecordBuffer();
        this.isQualified = null;
        this.rawRecord = "";
        this.headersHolder = new HeadersHolder();
        this.startedColumn = false;
        this.startedWithQualifier = false;
        this.hasMoreData = true;
        this.lastLetter = (char) 0;
        this.hasReadNextLine = false;
        this.columnsCount = 0;
        this.currentRecord = 0L;
        this.values = new String[10];
        this.initialized = false;
        this.closed = false;
        if (fileName == null) {
            throw new IllegalArgumentException("Parameter fileName can not be null.");
        }
        if (charset == null) {
            throw new IllegalArgumentException("Parameter charset can not be null.");
        }
        if (!new File(fileName).exists()) {
            throw new FileNotFoundException("File " + fileName + " does not exist.");
        }
        this.fileName = fileName;
        this.userSettings.Delimiter = delimiter;
        this.charset = charset;
        this.isQualified = new boolean[this.values.length];
    }

    public CsvReader(String fileName, char delimiter) throws FileNotFoundException {
        this(fileName, delimiter, Charset.forName("ISO-8859-1"));
    }

    public CsvReader(String fileName) throws FileNotFoundException {
        this(fileName, ',');
    }

    public CsvReader(Reader inputStream, char delimiter) {
        this.inputStream = null;
        this.fileName = null;
        this.userSettings = new UserSettings();
        this.charset = null;
        this.useCustomRecordDelimiter = false;
        this.dataBuffer = new DataBuffer();
        this.columnBuffer = new ColumnBuffer();
        this.rawBuffer = new RawRecordBuffer();
        this.isQualified = null;
        this.rawRecord = "";
        this.headersHolder = new HeadersHolder();
        this.startedColumn = false;
        this.startedWithQualifier = false;
        this.hasMoreData = true;
        this.lastLetter = (char) 0;
        this.hasReadNextLine = false;
        this.columnsCount = 0;
        this.currentRecord = 0L;
        this.values = new String[10];
        this.initialized = false;
        this.closed = false;
        if (inputStream == null) {
            throw new IllegalArgumentException("Parameter inputStream can not be null.");
        }
        this.inputStream = inputStream;
        this.userSettings.Delimiter = delimiter;
        this.initialized = true;
        this.isQualified = new boolean[this.values.length];
    }

    public CsvReader(Reader inputStream) {
        this(inputStream, ',');
    }

    public CsvReader(InputStream inputStream, char delimiter, Charset charset) {
        this(new InputStreamReader(inputStream, charset), delimiter);
    }

    public CsvReader(InputStream inputStream, Charset charset) {
        this(new InputStreamReader(inputStream, charset));
    }

    public boolean getCaptureRawRecord() {
        return this.userSettings.CaptureRawRecord;
    }

    public void setCaptureRawRecord(boolean captureRawRecord) {
        this.userSettings.CaptureRawRecord = captureRawRecord;
    }

    public String getRawRecord() {
        return this.rawRecord;
    }

    public boolean getTrimWhitespace() {
        return this.userSettings.TrimWhitespace;
    }

    public void setTrimWhitespace(boolean trimWhitespace) {
        this.userSettings.TrimWhitespace = trimWhitespace;
    }

    public char getDelimiter() {
        return this.userSettings.Delimiter;
    }

    public void setDelimiter(char delimiter) {
        this.userSettings.Delimiter = delimiter;
    }

    public char getRecordDelimiter() {
        return this.userSettings.RecordDelimiter;
    }

    public void setRecordDelimiter(char recordDelimiter) {
        this.useCustomRecordDelimiter = true;
        this.userSettings.RecordDelimiter = recordDelimiter;
    }

    public char getTextQualifier() {
        return this.userSettings.TextQualifier;
    }

    public void setTextQualifier(char textQualifier) {
        this.userSettings.TextQualifier = textQualifier;
    }

    public boolean getUseTextQualifier() {
        return this.userSettings.UseTextQualifier;
    }

    public void setUseTextQualifier(boolean useTextQualifier) {
        this.userSettings.UseTextQualifier = useTextQualifier;
    }

    public char getComment() {
        return this.userSettings.Comment;
    }

    public void setComment(char comment) {
        this.userSettings.Comment = comment;
    }

    public boolean getUseComments() {
        return this.userSettings.UseComments;
    }

    public void setUseComments(boolean useComments) {
        this.userSettings.UseComments = useComments;
    }

    public int getEscapeMode() {
        return this.userSettings.EscapeMode;
    }

    public void setEscapeMode(int escapeMode) throws IllegalArgumentException {
        if (escapeMode != 1 && escapeMode != 2) {
            throw new IllegalArgumentException("Parameter escapeMode must be a valid value.");
        }
        this.userSettings.EscapeMode = escapeMode;
    }

    public boolean getSkipEmptyRecords() {
        return this.userSettings.SkipEmptyRecords;
    }

    public void setSkipEmptyRecords(boolean skipEmptyRecords) {
        this.userSettings.SkipEmptyRecords = skipEmptyRecords;
    }

    public boolean getSafetySwitch() {
        return this.userSettings.SafetySwitch;
    }

    public void setSafetySwitch(boolean safetySwitch) {
        this.userSettings.SafetySwitch = safetySwitch;
    }

    public int getColumnCount() {
        return this.columnsCount;
    }

    public long getCurrentRecord() {
        return this.currentRecord - 1;
    }

    public int getHeaderCount() {
        return this.headersHolder.Length;
    }

    public String[] getHeaders() throws IOException {
        checkClosed();
        if (this.headersHolder.Headers == null) {
            return null;
        }
        String[] clone = new String[this.headersHolder.Length];
        System.arraycopy(this.headersHolder.Headers, 0, clone, 0, this.headersHolder.Length);
        return clone;
    }

    public void setHeaders(String[] headers) {
        this.headersHolder.Headers = headers;
        this.headersHolder.IndexByName.clear();
        if (headers != null) {
            this.headersHolder.Length = headers.length;
        } else {
            this.headersHolder.Length = 0;
        }
        for (int i = 0; i < this.headersHolder.Length; i++) {
            this.headersHolder.IndexByName.put(headers[i], new Integer(i));
        }
    }

    public String[] getValues() throws IOException {
        checkClosed();
        String[] clone = new String[this.columnsCount];
        System.arraycopy(this.values, 0, clone, 0, this.columnsCount);
        return clone;
    }

    public String get(int columnIndex) throws IOException {
        checkClosed();
        if (columnIndex > -1 && columnIndex < this.columnsCount) {
            return this.values[columnIndex];
        }
        return "";
    }

    public String get(String headerName) throws IOException {
        checkClosed();
        return get(getIndex(headerName));
    }

    public static CsvReader parse(String data) {
        if (data == null) {
            throw new IllegalArgumentException("Parameter data can not be null.");
        }
        return new CsvReader(new StringReader(data));
    }

    /* JADX WARN: Code restructure failed: missing block: B:100:0x0310, code lost:
    
        appendLetter('\n');
     */
    /* JADX WARN: Code restructure failed: missing block: B:101:0x0319, code lost:
    
        appendLetter('\r');
     */
    /* JADX WARN: Code restructure failed: missing block: B:102:0x0322, code lost:
    
        appendLetter('\t');
     */
    /* JADX WARN: Code restructure failed: missing block: B:103:0x032b, code lost:
    
        appendLetter('\b');
     */
    /* JADX WARN: Code restructure failed: missing block: B:104:0x0334, code lost:
    
        appendLetter('\f');
     */
    /* JADX WARN: Code restructure failed: missing block: B:105:0x033d, code lost:
    
        appendLetter(27);
     */
    /* JADX WARN: Code restructure failed: missing block: B:106:0x0346, code lost:
    
        appendLetter(11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:107:0x034f, code lost:
    
        appendLetter(7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:108:0x0358, code lost:
    
        r16 = 2;
        r15 = true;
        r17 = 1;
        r18 = (char) (r0 - '0');
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:110:0x037c, code lost:
    
        switch(r0) {
            case 68: goto L83;
            case 79: goto L82;
            case 85: goto L80;
            case 88: goto L81;
            case 100: goto L83;
            case 111: goto L82;
            case 117: goto L80;
            case 120: goto L81;
            default: goto L84;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:111:0x03c8, code lost:
    
        r16 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:112:0x03ce, code lost:
    
        r16 = 4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:113:0x03d4, code lost:
    
        r16 = 2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:114:0x03da, code lost:
    
        r16 = 3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:115:0x03dd, code lost:
    
        r15 = true;
        r17 = 0;
        r18 = 0;
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:116:0x03f9, code lost:
    
        r14 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:118:0x0401, code lost:
    
        if (r0 != r12) goto L89;
     */
    /* JADX WARN: Code restructure failed: missing block: B:119:0x0404, code lost:
    
        updateCurrentValue();
        r14 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:121:0x040f, code lost:
    
        if (r11 == false) goto L107;
     */
    /* JADX WARN: Code restructure failed: missing block: B:123:0x041a, code lost:
    
        if (r0 != r9.userSettings.Delimiter) goto L94;
     */
    /* JADX WARN: Code restructure failed: missing block: B:124:0x041d, code lost:
    
        endColumn();
     */
    /* JADX WARN: Code restructure failed: missing block: B:125:0x0467, code lost:
    
        r11 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:127:0x0428, code lost:
    
        if (r9.useCustomRecordDelimiter != false) goto L100;
     */
    /* JADX WARN: Code restructure failed: missing block: B:129:0x042e, code lost:
    
        if (r0 == '\r') goto L104;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x0a1f, code lost:
    
        if (r9.startedColumn != false) goto L268;
     */
    /* JADX WARN: Code restructure failed: missing block: B:131:0x0434, code lost:
    
        if (r0 == '\n') goto L104;
     */
    /* JADX WARN: Code restructure failed: missing block: B:132:0x0449, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:134:0x043b, code lost:
    
        if (r9.useCustomRecordDelimiter == false) goto L105;
     */
    /* JADX WARN: Code restructure failed: missing block: B:136:0x0446, code lost:
    
        if (r0 != r9.userSettings.RecordDelimiter) goto L105;
     */
    /* JADX WARN: Code restructure failed: missing block: B:137:0x0454, code lost:
    
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
        r13 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:139:0x050e, code lost:
    
        if (r10 != r9.userSettings.Delimiter) goto L123;
     */
    /* JADX WARN: Code restructure failed: missing block: B:140:0x0511, code lost:
    
        r9.lastLetter = r10;
        endColumn();
     */
    /* JADX WARN: Code restructure failed: missing block: B:142:0x0521, code lost:
    
        if (r9.useCustomRecordDelimiter == false) goto L136;
     */
    /* JADX WARN: Code restructure failed: missing block: B:144:0x052c, code lost:
    
        if (r10 != r9.userSettings.RecordDelimiter) goto L136;
     */
    /* JADX WARN: Code restructure failed: missing block: B:146:0x0533, code lost:
    
        if (r9.startedColumn != false) goto L133;
     */
    /* JADX WARN: Code restructure failed: missing block: B:148:0x053a, code lost:
    
        if (r9.columnsCount > 0) goto L133;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x0a2d, code lost:
    
        if (r9.lastLetter != r9.userSettings.Delimiter) goto L269;
     */
    /* JADX WARN: Code restructure failed: missing block: B:150:0x0544, code lost:
    
        if (r9.userSettings.SkipEmptyRecords != false) goto L134;
     */
    /* JADX WARN: Code restructure failed: missing block: B:151:0x0552, code lost:
    
        r9.dataBuffer.LineStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:152:0x0562, code lost:
    
        r9.lastLetter = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x0547, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:155:0x056e, code lost:
    
        if (r9.useCustomRecordDelimiter != false) goto L155;
     */
    /* JADX WARN: Code restructure failed: missing block: B:157:0x0574, code lost:
    
        if (r10 == '\r') goto L142;
     */
    /* JADX WARN: Code restructure failed: missing block: B:159:0x057a, code lost:
    
        if (r10 != '\n') goto L155;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x0a30, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:161:0x0581, code lost:
    
        if (r9.startedColumn != false) goto L152;
     */
    /* JADX WARN: Code restructure failed: missing block: B:163:0x0588, code lost:
    
        if (r9.columnsCount > 0) goto L152;
     */
    /* JADX WARN: Code restructure failed: missing block: B:165:0x0592, code lost:
    
        if (r9.userSettings.SkipEmptyRecords != false) goto L153;
     */
    /* JADX WARN: Code restructure failed: missing block: B:167:0x0598, code lost:
    
        if (r10 == '\r') goto L152;
     */
    /* JADX WARN: Code restructure failed: missing block: B:169:0x05a1, code lost:
    
        if (r9.lastLetter == '\r') goto L153;
     */
    /* JADX WARN: Code restructure failed: missing block: B:170:0x05af, code lost:
    
        r9.dataBuffer.LineStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:171:0x05bf, code lost:
    
        r9.lastLetter = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:172:0x05a4, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:174:0x05ce, code lost:
    
        if (r9.userSettings.UseComments == false) goto L162;
     */
    /* JADX WARN: Code restructure failed: missing block: B:176:0x05d5, code lost:
    
        if (r9.columnsCount != 0) goto L162;
     */
    /* JADX WARN: Code restructure failed: missing block: B:178:0x05e0, code lost:
    
        if (r10 != r9.userSettings.Comment) goto L162;
     */
    /* JADX WARN: Code restructure failed: missing block: B:179:0x05e3, code lost:
    
        r9.lastLetter = r10;
        skipLine();
     */
    /* JADX WARN: Code restructure failed: missing block: B:181:0x05f7, code lost:
    
        if (r9.userSettings.TrimWhitespace == false) goto L169;
     */
    /* JADX WARN: Code restructure failed: missing block: B:183:0x05fd, code lost:
    
        if (r10 == ' ') goto L168;
     */
    /* JADX WARN: Code restructure failed: missing block: B:185:0x0603, code lost:
    
        if (r10 != '\t') goto L169;
     */
    /* JADX WARN: Code restructure failed: missing block: B:186:0x0606, code lost:
    
        r9.startedColumn = true;
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:187:0x061e, code lost:
    
        r9.startedColumn = true;
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position;
        r11 = false;
        r12 = false;
        r13 = 1;
        r14 = 0;
        r15 = 0;
        r16 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:189:0x0643, code lost:
    
        if (r16 != false) goto L175;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x0043, code lost:
    
        r9.startedWithQualifier = false;
        r10 = r9.dataBuffer.Buffer[r9.dataBuffer.Position];
     */
    /* JADX WARN: Code restructure failed: missing block: B:191:0x0654, code lost:
    
        if (r9.dataBuffer.Position != r9.dataBuffer.Count) goto L175;
     */
    /* JADX WARN: Code restructure failed: missing block: B:192:0x0657, code lost:
    
        checkDataLength();
     */
    /* JADX WARN: Code restructure failed: missing block: B:194:0x09ef, code lost:
    
        if (r9.hasMoreData == false) goto L289;
     */
    /* JADX WARN: Code restructure failed: missing block: B:196:0x09f6, code lost:
    
        if (r9.startedColumn != false) goto L291;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x005f, code lost:
    
        if (r9.userSettings.UseTextQualifier == false) goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:201:0x0660, code lost:
    
        if (r16 != false) goto L178;
     */
    /* JADX WARN: Code restructure failed: missing block: B:202:0x0663, code lost:
    
        r10 = r9.dataBuffer.Buffer[r9.dataBuffer.Position];
     */
    /* JADX WARN: Code restructure failed: missing block: B:204:0x067a, code lost:
    
        if (r9.userSettings.UseTextQualifier != false) goto L188;
     */
    /* JADX WARN: Code restructure failed: missing block: B:206:0x0685, code lost:
    
        if (r9.userSettings.EscapeMode != 2) goto L188;
     */
    /* JADX WARN: Code restructure failed: missing block: B:208:0x068b, code lost:
    
        if (r10 != '\\') goto L188;
     */
    /* JADX WARN: Code restructure failed: missing block: B:210:0x068f, code lost:
    
        if (r11 == false) goto L187;
     */
    /* JADX WARN: Code restructure failed: missing block: B:211:0x0692, code lost:
    
        r11 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:212:0x095c, code lost:
    
        r9.lastLetter = r10;
        r16 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:213:0x0968, code lost:
    
        if (r9.startedColumn == false) goto L253;
     */
    /* JADX WARN: Code restructure failed: missing block: B:214:0x096b, code lost:
    
        r9.dataBuffer.Position++;
     */
    /* JADX WARN: Code restructure failed: missing block: B:215:0x097f, code lost:
    
        if (r9.userSettings.SafetySwitch == false) goto L253;
     */
    /* JADX WARN: Code restructure failed: missing block: B:217:0x099c, code lost:
    
        if (((r9.dataBuffer.Position - r9.dataBuffer.ColumnStart) + r9.columnBuffer.Position) <= 100000) goto L253;
     */
    /* JADX WARN: Code restructure failed: missing block: B:219:0x099f, code lost:
    
        close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x006a, code lost:
    
        if (r10 != r9.userSettings.TextQualifier) goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:220:0x09ea, code lost:
    
        throw new java.io.IOException("Maximum column length of 100,000 exceeded in column " + java.text.NumberFormat.getIntegerInstance().format(r9.columnsCount) + " in record " + java.text.NumberFormat.getIntegerInstance().format(r9.currentRecord) + ". Set the SafetySwitch property to false if you're expecting column lengths greater than 100,000 characters to avoid this error.");
     */
    /* JADX WARN: Code restructure failed: missing block: B:221:0x0697, code lost:
    
        updateCurrentValue();
        r11 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:223:0x06a1, code lost:
    
        if (r12 == false) goto L208;
     */
    /* JADX WARN: Code restructure failed: missing block: B:224:0x06a4, code lost:
    
        r14 = r14 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:225:0x06a9, code lost:
    
        switch(r13) {
            case 1: goto L192;
            case 2: goto L195;
            case 3: goto L198;
            case 4: goto L201;
            default: goto L204;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:226:0x06c8, code lost:
    
        r15 = (char) (((char) (r15 * 16)) + hexToDec(r10));
     */
    /* JADX WARN: Code restructure failed: missing block: B:227:0x06dd, code lost:
    
        if (r14 != 4) goto L204;
     */
    /* JADX WARN: Code restructure failed: missing block: B:228:0x06e0, code lost:
    
        r12 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:229:0x06e5, code lost:
    
        r15 = (char) (((char) (r15 * '\b')) + ((char) (r10 - '0')));
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x006d, code lost:
    
        r9.lastLetter = r10;
        r9.startedColumn = true;
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
        r9.startedWithQualifier = true;
        r11 = false;
        r12 = r9.userSettings.TextQualifier;
     */
    /* JADX WARN: Code restructure failed: missing block: B:230:0x06fb, code lost:
    
        if (r14 != 3) goto L204;
     */
    /* JADX WARN: Code restructure failed: missing block: B:231:0x06fe, code lost:
    
        r12 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:232:0x0703, code lost:
    
        r15 = (char) (((char) (r15 * '\n')) + ((char) (r10 - '0')));
     */
    /* JADX WARN: Code restructure failed: missing block: B:233:0x0719, code lost:
    
        if (r14 != 3) goto L204;
     */
    /* JADX WARN: Code restructure failed: missing block: B:234:0x071c, code lost:
    
        r12 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:235:0x0721, code lost:
    
        r15 = (char) (((char) (r15 * 16)) + hexToDec(r10));
     */
    /* JADX WARN: Code restructure failed: missing block: B:236:0x0736, code lost:
    
        if (r14 != 2) goto L204;
     */
    /* JADX WARN: Code restructure failed: missing block: B:237:0x0739, code lost:
    
        r12 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:239:0x073c, code lost:
    
        if (r12 != false) goto L207;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x009e, code lost:
    
        if (r9.userSettings.EscapeMode != 2) goto L14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:240:0x073f, code lost:
    
        appendLetter(r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:241:0x0748, code lost:
    
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:243:0x0763, code lost:
    
        if (r9.userSettings.EscapeMode != 2) goto L231;
     */
    /* JADX WARN: Code restructure failed: missing block: B:245:0x0767, code lost:
    
        if (r11 == false) goto L231;
     */
    /* JADX WARN: Code restructure failed: missing block: B:247:0x076b, code lost:
    
        switch(r10) {
            case 48: goto L222;
            case 49: goto L222;
            case 50: goto L222;
            case 51: goto L222;
            case 52: goto L222;
            case 53: goto L222;
            case 54: goto L222;
            case 55: goto L222;
            case 68: goto L223;
            case 79: goto L223;
            case 85: goto L223;
            case 88: goto L223;
            case 97: goto L221;
            case 98: goto L217;
            case 100: goto L223;
            case 101: goto L219;
            case 102: goto L218;
            case 110: goto L214;
            case 111: goto L223;
            case 114: goto L215;
            case 116: goto L216;
            case 117: goto L223;
            case 118: goto L220;
            case 120: goto L223;
            default: goto L230;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:248:0x0834, code lost:
    
        appendLetter('\n');
     */
    /* JADX WARN: Code restructure failed: missing block: B:249:0x083d, code lost:
    
        appendLetter('\r');
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x00a1, code lost:
    
        r12 = '\\';
     */
    /* JADX WARN: Code restructure failed: missing block: B:250:0x0846, code lost:
    
        appendLetter('\t');
     */
    /* JADX WARN: Code restructure failed: missing block: B:251:0x084f, code lost:
    
        appendLetter('\b');
     */
    /* JADX WARN: Code restructure failed: missing block: B:252:0x0858, code lost:
    
        appendLetter('\f');
     */
    /* JADX WARN: Code restructure failed: missing block: B:253:0x0861, code lost:
    
        appendLetter(27);
     */
    /* JADX WARN: Code restructure failed: missing block: B:254:0x086a, code lost:
    
        appendLetter(11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:255:0x0873, code lost:
    
        appendLetter(7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:256:0x087c, code lost:
    
        r13 = 2;
        r12 = true;
        r14 = 1;
        r15 = (char) (r10 - '0');
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:258:0x089f, code lost:
    
        switch(r10) {
            case 68: goto L228;
            case 79: goto L227;
            case 85: goto L225;
            case 88: goto L226;
            case 100: goto L228;
            case 111: goto L227;
            case 117: goto L225;
            case 120: goto L226;
            default: goto L229;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:259:0x08e8, code lost:
    
        r13 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x00a4, code lost:
    
        r13 = false;
        r14 = false;
        r15 = false;
        r16 = 1;
        r17 = 0;
        r18 = 0;
        r9.dataBuffer.Position++;
     */
    /* JADX WARN: Code restructure failed: missing block: B:260:0x08ee, code lost:
    
        r13 = 4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:261:0x08f4, code lost:
    
        r13 = 2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:262:0x08fa, code lost:
    
        r13 = 3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:263:0x08fd, code lost:
    
        r12 = true;
        r14 = 0;
        r15 = 0;
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:264:0x0918, code lost:
    
        r11 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:266:0x0925, code lost:
    
        if (r10 != r9.userSettings.Delimiter) goto L234;
     */
    /* JADX WARN: Code restructure failed: missing block: B:267:0x0928, code lost:
    
        endColumn();
     */
    /* JADX WARN: Code restructure failed: missing block: B:269:0x0933, code lost:
    
        if (r9.useCustomRecordDelimiter != false) goto L240;
     */
    /* JADX WARN: Code restructure failed: missing block: B:271:0x0939, code lost:
    
        if (r10 == '\r') goto L244;
     */
    /* JADX WARN: Code restructure failed: missing block: B:273:0x093f, code lost:
    
        if (r10 == '\n') goto L244;
     */
    /* JADX WARN: Code restructure failed: missing block: B:274:0x0954, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:276:0x0946, code lost:
    
        if (r9.useCustomRecordDelimiter == false) goto L245;
     */
    /* JADX WARN: Code restructure failed: missing block: B:278:0x0951, code lost:
    
        if (r10 != r9.userSettings.RecordDelimiter) goto L245;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x00d1, code lost:
    
        if (r9.dataBuffer.Position != r9.dataBuffer.Count) goto L18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:280:0x0a3f, code lost:
    
        if (r9.userSettings.CaptureRawRecord == false) goto L278;
     */
    /* JADX WARN: Code restructure failed: missing block: B:282:0x0a46, code lost:
    
        if (r9.hasMoreData == false) goto L277;
     */
    /* JADX WARN: Code restructure failed: missing block: B:284:0x0a50, code lost:
    
        if (r9.rawBuffer.Position != 0) goto L276;
     */
    /* JADX WARN: Code restructure failed: missing block: B:285:0x0a53, code lost:
    
        r9.rawRecord = new java.lang.String(r9.dataBuffer.Buffer, r9.dataBuffer.LineStart, (r9.dataBuffer.Position - r9.dataBuffer.LineStart) - 1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:287:0x0afa, code lost:
    
        return r9.hasReadNextLine;
     */
    /* JADX WARN: Code restructure failed: missing block: B:288:0x0a80, code lost:
    
        r9.rawRecord = java.lang.String.valueOf(new java.lang.String(r9.rawBuffer.Buffer, 0, r9.rawBuffer.Position)) + new java.lang.String(r9.dataBuffer.Buffer, r9.dataBuffer.LineStart, (r9.dataBuffer.Position - r9.dataBuffer.LineStart) - 1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:289:0x0ad3, code lost:
    
        r9.rawRecord = new java.lang.String(r9.rawBuffer.Buffer, 0, r9.rawBuffer.Position);
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x00d4, code lost:
    
        checkDataLength();
     */
    /* JADX WARN: Code restructure failed: missing block: B:290:0x0af0, code lost:
    
        r9.rawRecord = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:2:0x0028, code lost:
    
        if (r9.hasMoreData != false) goto L4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x04f9, code lost:
    
        if (r9.hasMoreData == false) goto L287;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x0500, code lost:
    
        if (r9.startedColumn != false) goto L288;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x09fd, code lost:
    
        if (r9.hasMoreData == false) goto L260;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x0a00, code lost:
    
        r9.dataBuffer.Position++;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x00db, code lost:
    
        r0 = r9.dataBuffer.Buffer[r9.dataBuffer.Position];
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x00ed, code lost:
    
        if (r13 == false) goto L34;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x00f0, code lost:
    
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x0108, code lost:
    
        if (r0 != r9.userSettings.Delimiter) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x010b, code lost:
    
        endColumn();
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x0469, code lost:
    
        r9.lastLetter = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x0472, code lost:
    
        if (r9.startedColumn == false) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x0475, code lost:
    
        r9.dataBuffer.Position++;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0489, code lost:
    
        if (r9.userSettings.SafetySwitch == false) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x04a6, code lost:
    
        if (((r9.dataBuffer.Position - r9.dataBuffer.ColumnStart) + r9.columnBuffer.Position) <= 100000) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:4:0x0039, code lost:
    
        if (r9.dataBuffer.Position != r9.dataBuffer.Count) goto L7;
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x04a9, code lost:
    
        close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:52:0x04f4, code lost:
    
        throw new java.io.IOException("Maximum column length of 100,000 exceeded in column " + java.text.NumberFormat.getIntegerInstance().format(r9.columnsCount) + " in record " + java.text.NumberFormat.getIntegerInstance().format(r9.currentRecord) + ". Set the SafetySwitch property to false if you're expecting column lengths greater than 100,000 characters to avoid this error.");
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x0116, code lost:
    
        if (r9.useCustomRecordDelimiter != false) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x011c, code lost:
    
        if (r0 == '\r') goto L33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x0122, code lost:
    
        if (r0 == '\n') goto L33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:5:0x003c, code lost:
    
        checkDataLength();
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x0137, code lost:
    
        endColumn();
        endRecord();
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x0129, code lost:
    
        if (r9.useCustomRecordDelimiter == false) goto L107;
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x0134, code lost:
    
        if (r0 != r9.userSettings.RecordDelimiter) goto L107;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x0144, code lost:
    
        if (r15 == false) goto L54;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x0147, code lost:
    
        r17 = r17 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x014c, code lost:
    
        switch(r16) {
            case 1: goto L38;
            case 2: goto L41;
            case 3: goto L44;
            case 4: goto L47;
            default: goto L50;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x016c, code lost:
    
        r18 = (char) (((char) (r18 * 16)) + hexToDec(r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0181, code lost:
    
        if (r17 != 4) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x0184, code lost:
    
        r15 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x018a, code lost:
    
        r18 = (char) (((char) (r18 * '\b')) + ((char) (r0 - '0')));
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x01a0, code lost:
    
        if (r17 != 3) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x01a3, code lost:
    
        r15 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:75:0x01a9, code lost:
    
        r18 = (char) (((char) (r18 * '\n')) + ((char) (r0 - '0')));
     */
    /* JADX WARN: Code restructure failed: missing block: B:76:0x01bf, code lost:
    
        if (r17 != 3) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:77:0x01c2, code lost:
    
        r15 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:78:0x01c8, code lost:
    
        r18 = (char) (((char) (r18 * 16)) + hexToDec(r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x01dd, code lost:
    
        if (r17 != 2) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:7:0x0a11, code lost:
    
        if (r9.hasMoreData == false) goto L281;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x01e0, code lost:
    
        r15 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:82:0x01e5, code lost:
    
        if (r15 != false) goto L53;
     */
    /* JADX WARN: Code restructure failed: missing block: B:83:0x01e8, code lost:
    
        appendLetter(r18);
     */
    /* JADX WARN: Code restructure failed: missing block: B:84:0x01f1, code lost:
    
        r9.dataBuffer.ColumnStart = r9.dataBuffer.Position + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:86:0x020c, code lost:
    
        if (r0 != r9.userSettings.TextQualifier) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:0x0211, code lost:
    
        if (r14 == false) goto L59;
     */
    /* JADX WARN: Code restructure failed: missing block: B:89:0x0214, code lost:
    
        r14 = false;
        r11 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x021c, code lost:
    
        updateCurrentValue();
     */
    /* JADX WARN: Code restructure failed: missing block: B:91:0x0228, code lost:
    
        if (r9.userSettings.EscapeMode != 1) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x022b, code lost:
    
        r14 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:93:0x022e, code lost:
    
        r11 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:95:0x023b, code lost:
    
        if (r9.userSettings.EscapeMode != 2) goto L86;
     */
    /* JADX WARN: Code restructure failed: missing block: B:97:0x0240, code lost:
    
        if (r14 == false) goto L86;
     */
    /* JADX WARN: Code restructure failed: missing block: B:99:0x0244, code lost:
    
        switch(r0) {
            case 48: goto L77;
            case 49: goto L77;
            case 50: goto L77;
            case 51: goto L77;
            case 52: goto L77;
            case 53: goto L77;
            case 54: goto L77;
            case 55: goto L77;
            case 68: goto L78;
            case 79: goto L78;
            case 85: goto L78;
            case 88: goto L78;
            case 97: goto L76;
            case 98: goto L72;
            case 100: goto L78;
            case 101: goto L74;
            case 102: goto L73;
            case 110: goto L69;
            case 111: goto L78;
            case 114: goto L70;
            case 116: goto L71;
            case 117: goto L78;
            case 118: goto L75;
            case 120: goto L78;
            default: goto L85;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x0a18, code lost:
    
        if (r9.hasReadNextLine == false) goto L285;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public boolean readRecord() throws java.io.IOException {
        /*
            Method dump skipped, instructions count: 2811
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.util.csv.CsvReader.readRecord():boolean");
    }

    private void checkDataLength() throws IOException {
        if (!this.initialized) {
            if (this.fileName != null) {
                this.inputStream = new BufferedReader(new InputStreamReader(new FileInputStream(this.fileName), this.charset), StaticSettings.MAX_FILE_BUFFER_SIZE);
            }
            this.charset = null;
            this.initialized = true;
        }
        updateCurrentValue();
        if (this.userSettings.CaptureRawRecord && this.dataBuffer.Count > 0) {
            if (this.rawBuffer.Buffer.length - this.rawBuffer.Position < this.dataBuffer.Count - this.dataBuffer.LineStart) {
                int newLength = this.rawBuffer.Buffer.length + Math.max(this.dataBuffer.Count - this.dataBuffer.LineStart, this.rawBuffer.Buffer.length);
                char[] holder = new char[newLength];
                System.arraycopy(this.rawBuffer.Buffer, 0, holder, 0, this.rawBuffer.Position);
                this.rawBuffer.Buffer = holder;
            }
            System.arraycopy(this.dataBuffer.Buffer, this.dataBuffer.LineStart, this.rawBuffer.Buffer, this.rawBuffer.Position, this.dataBuffer.Count - this.dataBuffer.LineStart);
            this.rawBuffer.Position += this.dataBuffer.Count - this.dataBuffer.LineStart;
        }
        try {
            this.dataBuffer.Count = this.inputStream.read(this.dataBuffer.Buffer, 0, this.dataBuffer.Buffer.length);
            if (this.dataBuffer.Count == -1) {
                this.hasMoreData = false;
            }
            this.dataBuffer.Position = 0;
            this.dataBuffer.LineStart = 0;
            this.dataBuffer.ColumnStart = 0;
        } catch (IOException ex) {
            close();
            throw ex;
        }
    }

    public boolean readHeaders() throws IOException {
        boolean result = readRecord();
        this.headersHolder.Length = this.columnsCount;
        this.headersHolder.Headers = new String[this.columnsCount];
        for (int i = 0; i < this.headersHolder.Length; i++) {
            String columnValue = get(i);
            this.headersHolder.Headers[i] = columnValue;
            this.headersHolder.IndexByName.put(columnValue, new Integer(i));
        }
        if (result) {
            this.currentRecord--;
        }
        this.columnsCount = 0;
        return result;
    }

    public String getHeader(int columnIndex) throws IOException {
        checkClosed();
        if (columnIndex > -1 && columnIndex < this.headersHolder.Length) {
            return this.headersHolder.Headers[columnIndex];
        }
        return "";
    }

    public boolean isQualified(int columnIndex) throws IOException {
        checkClosed();
        if (columnIndex < this.columnsCount && columnIndex > -1) {
            return this.isQualified[columnIndex];
        }
        return false;
    }

    private void endColumn() throws IOException {
        String currentValue = "";
        if (this.startedColumn) {
            if (this.columnBuffer.Position == 0) {
                if (this.dataBuffer.ColumnStart < this.dataBuffer.Position) {
                    int lastLetter = this.dataBuffer.Position - 1;
                    if (this.userSettings.TrimWhitespace && !this.startedWithQualifier) {
                        while (lastLetter >= this.dataBuffer.ColumnStart && (this.dataBuffer.Buffer[lastLetter] == ' ' || this.dataBuffer.Buffer[lastLetter] == '\t')) {
                            lastLetter--;
                        }
                    }
                    currentValue = new String(this.dataBuffer.Buffer, this.dataBuffer.ColumnStart, (lastLetter - this.dataBuffer.ColumnStart) + 1);
                }
            } else {
                updateCurrentValue();
                int lastLetter2 = this.columnBuffer.Position - 1;
                if (this.userSettings.TrimWhitespace && !this.startedWithQualifier) {
                    while (lastLetter2 >= 0 && (this.columnBuffer.Buffer[lastLetter2] == ' ' || this.columnBuffer.Buffer[lastLetter2] == ' ')) {
                        lastLetter2--;
                    }
                }
                currentValue = new String(this.columnBuffer.Buffer, 0, lastLetter2 + 1);
            }
        }
        this.columnBuffer.Position = 0;
        this.startedColumn = false;
        if (this.columnsCount >= 100000 && this.userSettings.SafetySwitch) {
            close();
            throw new IOException("Maximum column count of 100,000 exceeded in record " + NumberFormat.getIntegerInstance().format(this.currentRecord) + ". Set the SafetySwitch property to false if you're expecting more than 100,000 columns per record to avoid this error.");
        }
        if (this.columnsCount == this.values.length) {
            int newLength = this.values.length * 2;
            String[] holder = new String[newLength];
            System.arraycopy(this.values, 0, holder, 0, this.values.length);
            this.values = holder;
            boolean[] qualifiedHolder = new boolean[newLength];
            System.arraycopy(this.isQualified, 0, qualifiedHolder, 0, this.isQualified.length);
            this.isQualified = qualifiedHolder;
        }
        this.values[this.columnsCount] = currentValue;
        this.isQualified[this.columnsCount] = this.startedWithQualifier;
        this.columnsCount++;
    }

    private void appendLetter(char letter) {
        if (this.columnBuffer.Position == this.columnBuffer.Buffer.length) {
            int newLength = this.columnBuffer.Buffer.length * 2;
            char[] holder = new char[newLength];
            System.arraycopy(this.columnBuffer.Buffer, 0, holder, 0, this.columnBuffer.Position);
            this.columnBuffer.Buffer = holder;
        }
        char[] cArr = this.columnBuffer.Buffer;
        ColumnBuffer columnBuffer = this.columnBuffer;
        int i = columnBuffer.Position;
        columnBuffer.Position = i + 1;
        cArr[i] = letter;
        this.dataBuffer.ColumnStart = this.dataBuffer.Position + 1;
    }

    private void updateCurrentValue() {
        if (this.startedColumn && this.dataBuffer.ColumnStart < this.dataBuffer.Position) {
            if (this.columnBuffer.Buffer.length - this.columnBuffer.Position < this.dataBuffer.Position - this.dataBuffer.ColumnStart) {
                int newLength = this.columnBuffer.Buffer.length + Math.max(this.dataBuffer.Position - this.dataBuffer.ColumnStart, this.columnBuffer.Buffer.length);
                char[] holder = new char[newLength];
                System.arraycopy(this.columnBuffer.Buffer, 0, holder, 0, this.columnBuffer.Position);
                this.columnBuffer.Buffer = holder;
            }
            System.arraycopy(this.dataBuffer.Buffer, this.dataBuffer.ColumnStart, this.columnBuffer.Buffer, this.columnBuffer.Position, this.dataBuffer.Position - this.dataBuffer.ColumnStart);
            this.columnBuffer.Position += this.dataBuffer.Position - this.dataBuffer.ColumnStart;
        }
        this.dataBuffer.ColumnStart = this.dataBuffer.Position + 1;
    }

    private void endRecord() throws IOException {
        this.hasReadNextLine = true;
        this.currentRecord++;
    }

    public int getIndex(String headerName) throws IOException {
        checkClosed();
        Object indexValue = this.headersHolder.IndexByName.get(headerName);
        if (indexValue != null) {
            return ((Integer) indexValue).intValue();
        }
        return -1;
    }

    public boolean skipRecord() throws IOException {
        checkClosed();
        boolean recordRead = false;
        if (this.hasMoreData) {
            recordRead = readRecord();
            if (recordRead) {
                this.currentRecord--;
            }
        }
        return recordRead;
    }

    public boolean skipLine() throws IOException {
        checkClosed();
        this.columnsCount = 0;
        boolean skippedLine = false;
        if (this.hasMoreData) {
            boolean foundEol = false;
            do {
                if (this.dataBuffer.Position == this.dataBuffer.Count) {
                    checkDataLength();
                } else {
                    skippedLine = true;
                    char currentLetter = this.dataBuffer.Buffer[this.dataBuffer.Position];
                    if (currentLetter == '\r' || currentLetter == '\n') {
                        foundEol = true;
                    }
                    this.lastLetter = currentLetter;
                    if (!foundEol) {
                        this.dataBuffer.Position++;
                    }
                }
                if (!this.hasMoreData) {
                    break;
                }
            } while (!foundEol);
            this.columnBuffer.Position = 0;
            this.dataBuffer.LineStart = this.dataBuffer.Position + 1;
        }
        this.rawBuffer.Position = 0;
        this.rawRecord = "";
        return skippedLine;
    }

    public void close() {
        if (!this.closed) {
            close(true);
            this.closed = true;
        }
    }

    private void close(boolean closing) {
        if (!this.closed) {
            if (closing) {
                this.charset = null;
                this.headersHolder.Headers = null;
                this.headersHolder.IndexByName = null;
                this.dataBuffer.Buffer = null;
                this.columnBuffer.Buffer = null;
                this.rawBuffer.Buffer = null;
            }
            try {
                if (this.initialized) {
                    this.inputStream.close();
                }
            } catch (Exception unused) {
            }
            this.inputStream = null;
            this.closed = true;
        }
    }

    private void checkClosed() throws IOException {
        if (this.closed) {
            throw new IOException("This instance of the CsvReader class has already been closed.");
        }
    }

    protected void finalize() {
        close(false);
    }

    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$ComplexEscape.class */
    private class ComplexEscape {
        private static final int UNICODE = 1;
        private static final int OCTAL = 2;
        private static final int DECIMAL = 3;
        private static final int HEX = 4;

        private ComplexEscape() {
        }
    }

    private static char hexToDec(char hex) {
        char result;
        if (hex >= 'a') {
            result = (char) ((hex - 'a') + 10);
        } else if (hex >= 'A') {
            result = (char) ((hex - 'A') + 10);
        } else {
            result = (char) (hex - '0');
        }
        return result;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$DataBuffer.class */
    public class DataBuffer {
        public char[] Buffer = new char[StaticSettings.MAX_BUFFER_SIZE];
        public int Position = 0;
        public int Count = 0;
        public int ColumnStart = 0;
        public int LineStart = 0;

        public DataBuffer() {
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$ColumnBuffer.class */
    public class ColumnBuffer {
        public char[] Buffer = new char[50];
        public int Position = 0;

        public ColumnBuffer() {
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$RawRecordBuffer.class */
    public class RawRecordBuffer {
        public char[] Buffer = new char[500];
        public int Position = 0;

        public RawRecordBuffer() {
        }
    }

    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$Letters.class */
    private class Letters {
        public static final char LF = '\n';
        public static final char CR = '\r';
        public static final char QUOTE = '\"';
        public static final char COMMA = ',';
        public static final char SPACE = ' ';
        public static final char TAB = '\t';
        public static final char POUND = '#';
        public static final char BACKSLASH = '\\';
        public static final char NULL = 0;
        public static final char BACKSPACE = '\b';
        public static final char FORM_FEED = '\f';
        public static final char ESCAPE = 27;
        public static final char VERTICAL_TAB = 11;
        public static final char ALERT = 7;

        private Letters() {
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$UserSettings.class */
    public class UserSettings {
        public boolean CaseSensitive = true;
        public char TextQualifier = '\"';
        public boolean TrimWhitespace = true;
        public boolean UseTextQualifier = true;
        public char Delimiter = ',';
        public char RecordDelimiter = 0;
        public char Comment = '#';
        public boolean UseComments = false;
        public int EscapeMode = 1;
        public boolean SafetySwitch = true;
        public boolean SkipEmptyRecords = true;
        public boolean CaptureRawRecord = true;

        public UserSettings() {
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$HeadersHolder.class */
    public class HeadersHolder {
        public String[] Headers = null;
        public int Length = 0;
        public HashMap IndexByName = new HashMap();

        public HeadersHolder() {
        }
    }

    /* loaded from: com_jiuqi_util_csv.jar:com/jiuqi/util/csv/CsvReader$StaticSettings.class */
    private class StaticSettings {
        public static final int MAX_BUFFER_SIZE = 1024;
        public static final int MAX_FILE_BUFFER_SIZE = 4096;
        public static final int INITIAL_COLUMN_COUNT = 10;
        public static final int INITIAL_COLUMN_BUFFER_SIZE = 50;

        private StaticSettings() {
        }
    }
}
